@@ -4,11 +4,11 @@
  * used by configure to dynamically assign those values 
  * to documentation files.
  */
-const char *version_string = "0.17";
+const char *version_string = "0.18";
 const char *program_name   = "nwipe";
-const char *author_name    = "Andy Beverley";
-const char *email_address  = "andy@andybev.com";
-const char *years          = "2012";
+const char *author_name    = "Martijn van Brummelen";
+const char *email_address  = "git@brumit.nl";
+const char *years          = "2016";
 const char *copyright      = "Copyright Darik Horn <dajhorn-dban@vanadac.com>\n\
 Modifications to original dwipe Copyright Andy Beverley <andy@andybev.com>\n\
 This is free software; see the source for copying conditions.\n\
